pub type HashFn<Key> = dyn Fn(&Key) -> KeyHash + Send + Sync;Expand description
Defines the function for calculating the hash of the incoming key. This hash is used to put the key in crate::cache::policy::cache_weight::CacheWeight.
By default, DefaultHasher is used that uses SipHasher13 as the hash function.