Module stats
tinylfu_
cached
0.0.4
Module stats
Module Items
Structs
Enums
In tinylfu_
cached::
cache
tinylfu_cached
::
cache
Module
stats
Structs

Stats
Summary
StatsSummary is view representation of various stats represented by
StatsType
.
Enums

Stats
Type
Defines various stats that are measured in the cache.