StatsType

Enum StatsType 

#[non_exhaustive]
#[repr(usize)]
pub enum StatsType { CacheHits = 0, CacheMisses = 1, KeysAdded = 2, KeysDeleted = 3, KeysUpdated = 4, KeysRejected = 5, WeightAdded = 6, WeightRemoved = 7, AccessAdded = 8, AccessDropped = 9, }
Defines various stats that are measured in the cache.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


CacheHits = 0

Defines the number of hits for the keys



CacheMisses = 1

Defines the number of misses for the keys



KeysAdded = 2

Defines the number of keys added



KeysDeleted = 3

Defines the number of keys deleted



KeysUpdated = 4

Defines the number of keys updated



KeysRejected = 5

Defines the number of keys rejected



WeightAdded = 6

Defines the total weight added



WeightRemoved = 7

Defines the total weight removed



AccessAdded = 8

Defines the total number of gets registered in the frequency counter



AccessDropped = 9

Defines the total number of gets dropped